Module implementation

Different implementations of genome string representations.

Modules

alphabets
Implementations of various common genomic alphabets.
array_kmer
A simple representation of a k-mer as an array.
bit_array_kmer
A simple representation of a k-mer as an array.
bit_vec_sequence
A representation of a genome as Vec<usize> where each character is encoded as bits.
bit_vec_sequence_store
A vector sequence store where each character is encoded as two bits.
handle_sequence_store
An “anti” sequence store that stores the sequences in the handles.
vec_sequence
A simple representation of a genome as Vec<u8>.
vec_sequence_store
An ASCII vector based sequence store.

Type Aliases

DefaultGenome
The default genome type that achieves a good balance between speed and size.
DefaultSequenceStore
The default genome sequence store type that achieves a good balance between speed and size.
DefaultSequenceStoreHandle
The handle type of the default genome sequence store type.
DefaultSubGenome
The default genome subsequence type that achieves a good balance between speed and size.