pub type DefaultSequenceStoreHandle<AlphabetType> = <BitVectorSequenceStore<AlphabetType> as SequenceStore<AlphabetType>>::Handle;Expand description
The handle type of the default genome sequence store type.
pub type DefaultSequenceStoreHandle<AlphabetType> = <BitVectorSequenceStore<AlphabetType> as SequenceStore<AlphabetType>>::Handle;The handle type of the default genome sequence store type.