SubstitutionDistanceOneNeighborIterator

Struct SubstitutionDistanceOneNeighborIterator 

pub struct SubstitutionDistanceOneNeighborIterator<AlphabetType: Alphabet, Sequence: OwnedGenomeSequence<AlphabetType, Subsequence> + GenomeSequenceMut<AlphabetType, Subsequence> + Sized, Subsequence: GenomeSequenceMut<AlphabetType, Subsequence> + ?Sized> { /* private fields */ }
An iterator over the genome sequences that are exactly one substitution away from the given genome sequence.

In other words, all sequences with hamming distance one of the same length. While the type works like an iterator, it does not implement the iterator trait due to limitations of the type system.

Implementations

Source

impl<AlphabetType: Alphabet, Sequence: OwnedGenomeSequence<AlphabetType, Subsequence> + GenomeSequenceMut<AlphabetType, Subsequence> + Sized, Subsequence: GenomeSequenceMut<AlphabetType, Subsequence> + ?Sized> SubstitutionDistanceOneNeighborIterator<AlphabetType, Sequence, Subsequence>

pub fn next<'this: 'returned_reference, 'returned_reference>( &'this mut self, ) -> Option<&'returned_reference Subsequence>

Like the Iterator::next function. The returned reference must be dropped before next is called a second time.