OwnedGenomeSequence

Trait OwnedGenomeSequence 

pub trait OwnedGenomeSequence<AlphabetType: Alphabet, GenomeSubsequence: GenomeSequence<AlphabetType, GenomeSubsequence> + ?Sized>:
    GenomeSequence<AlphabetType, GenomeSubsequence>
    + FromIterator<AlphabetType::CharacterType>
    + OwnedSequence<AlphabetType::CharacterType, GenomeSubsequence> {
    // Provided methods
    fn clone_as_reverse_complement(&self) -> Self { ... }
    fn from_iter_u8<T: IntoIterator<Item = u8>>(
        iter: T,
    ) -> Result<Self, AlphabetError> { ... }
    fn from_slice_u8(slice: &[u8]) -> Result<Self, AlphabetError> { ... }
}
A genome sequence that is owned, i.e. not a reference.

Provided Methods

fn clone_as_reverse_complement(&self) -> Self

Returns the reverse complement of this genome. Panics if this genome is not valid.

fn from_iter_u8<T: IntoIterator<Item = u8>>( iter: T, ) -> Result<Self, AlphabetError>

Constructs an owned genome sequence from an IntoIter over ASCII characters. If any character is not part of the alphabet, then None is returned.

fn from_slice_u8(slice: &[u8]) -> Result<Self, AlphabetError>

Constructs an owned genome sequence from a slice of ASCII characters. If any character is not part of the alphabet, then None is returned.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<AlphabetType: Alphabet> OwnedGenomeSequence<AlphabetType, SliceSubGenome<AlphabetType>> for VectorGenome<AlphabetType>

Source

impl<AlphabetType: Alphabet, BitStoreType: BitStore> OwnedGenomeSequence<AlphabetType, BitVectorSubGenome<AlphabetType, BitStoreType>> for BitVectorGenome<AlphabetType, BitStoreType>

Source

impl<const K: usize, AlphabetType: Alphabet> OwnedGenomeSequence<AlphabetType, SliceSubGenome<AlphabetType>> for ArrayKmer<K, AlphabetType>

Source

impl<const K: usize, AlphabetType: Alphabet, BitArrayType: BitViewSized + BitStore + BitView<Store = BitArrayType>> OwnedGenomeSequence<AlphabetType, BitVectorSubGenome<AlphabetType, BitArrayType>> for BitArrayKmer<K, AlphabetType, BitArrayType>