HandleWithLength

Trait HandleWithLength 

pub trait HandleWithLength {
    // Required method
    fn len(&self) -> usize;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
A handle of a sequence store that can compute the length of the referred sequence without retrieving the sequence.

Required Methods

fn len(&self) -> usize

Returns the length of the sequence referred by this handle without retrieving the sequence.

Provided Methods

fn is_empty(&self) -> bool

Returns true if the length of the sequence referred by this handle is zero, without retrieving the sequence.

Implementors

Source

impl<AlphabetType: Alphabet> HandleWithLength for BitVectorSequenceStoreHandle<AlphabetType>

Source

impl<AlphabetType: Alphabet> HandleWithLength for VectorSequenceStoreHandle<AlphabetType>