HandleWithSubsequence

Trait HandleWithSubsequence 

pub trait HandleWithSubsequence<RangeType> {
    // Required method
    fn subsequence_handle(&self, range: RangeType) -> Self;
}
A handle that allows the creation of handles referring arbitrary subsequences of this handle.

Required Methods

fn subsequence_handle(&self, range: RangeType) -> Self

Returns a new handle that refers the subsequence of this handle as indicated by the range. This method may panic if the range does not define a subsequence of the sequence referred by this handle. However, since the handle might not know anything about the sequence it refers, it might also silently ignore such errors.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors