Crate compact_genome[−][src]
This crate abstracts over the representation of a genome string, allowing for different implementations that are catered to different use-cases.
Modules
Different implementations of genome string representations.
The traits providing the abstractions of this crate.