Different implementations of genome string representations.
Modules
- alphabets
- Implementations of various common genomic alphabets.
- array_
kmer - A simple representation of a k-mer as an array.
- bit_
array_ kmer - A simple representation of a k-mer as an array.
- bit_
vec_ sequence - A representation of a genome as
Vec<usize>where each character is encoded as bits. - bit_
vec_ sequence_ store - A vector sequence store where each character is encoded as two bits.
- handle_
sequence_ store - An “anti” sequence store that stores the sequences in the handles.
- vec_
sequence - A simple representation of a genome as
Vec<u8>. - vec_
sequence_ store - An ASCII vector based sequence store.
Type Aliases
- Default
Genome - The default genome type that achieves a good balance between speed and size.
- Default
Sequence Store - The default genome sequence store type that achieves a good balance between speed and size.
- Default
Sequence Store Handle - The handle type of the default genome sequence store type.
- Default
SubGenome - The default genome subsequence type that achieves a good balance between speed and size.