Module compact_genome::interface::sequence_store
source · Expand description
Traits for genome sequence stores.
Traits
- A handle of a sequence store that can compute the length of the referred sequence without retrieving the sequence.
- A handle that allows the creation of handles referring arbitrary subsequences of this handle.
- A sequence store that is able to map from references to sequences back to handles.
- A store for sequence data, which gives out handles that can be used to retrieve concrete sequences.