pub trait HandleWithLength {
// Required method
fn len(&self) -> usize;
// Provided method
fn is_empty(&self) -> bool { ... }
}Expand description
A handle of a sequence store that can compute the length of the referred sequence without retrieving the sequence.