pub trait InverseMappingSequenceStore<AlphabetType: Alphabet>: SequenceStore<AlphabetType> {
// Required method
fn map_sequence_ref_to_handle(
&self,
sequence_ref: &Self::SequenceRef,
) -> Self::Handle;
}Expand description
A sequence store that is able to map from references to sequences back to handles.
Required Methods
Sourcefn map_sequence_ref_to_handle(
&self,
sequence_ref: &Self::SequenceRef,
) -> Self::Handle
fn map_sequence_ref_to_handle( &self, sequence_ref: &Self::SequenceRef, ) -> Self::Handle
Returns a handle that refers the given sequence reference.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.