pub trait InverseMappingSequenceStore<AlphabetType: Alphabet>: SequenceStore<AlphabetType> {
    // Required method
    fn map_sequence_ref_to_handle(
        &self,
        sequence_ref: &Self::SequenceRef,
    ) -> Self::Handle;
}
A sequence store that is able to map from references to sequences back to handles.

Required Methods

source

fn map_sequence_ref_to_handle( &self, sequence_ref: &Self::SequenceRef, ) -> Self::Handle

Returns a handle that refers the given sequence reference.

Object Safety

This trait is not object safe.

Implementors

source

impl<AlphabetType: Alphabet + 'static> InverseMappingSequenceStore<AlphabetType> for BitVectorSequenceStore<AlphabetType>

source

impl<AlphabetType: Alphabet + 'static> InverseMappingSequenceStore<AlphabetType> for VectorSequenceStore<AlphabetType>